summaryrefslogtreecommitdiffstats
path: root/kviewshell/plugins/djvu/libdjvu/DjVuFile.h
diff options
context:
space:
mode:
Diffstat (limited to 'kviewshell/plugins/djvu/libdjvu/DjVuFile.h')
-rw-r--r--kviewshell/plugins/djvu/libdjvu/DjVuFile.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kviewshell/plugins/djvu/libdjvu/DjVuFile.h b/kviewshell/plugins/djvu/libdjvu/DjVuFile.h
index 6f81c8e4..e81ef2d5 100644
--- a/kviewshell/plugins/djvu/libdjvu/DjVuFile.h
+++ b/kviewshell/plugins/djvu/libdjvu/DjVuFile.h
@@ -215,9 +215,9 @@ public:
GP<IW44Image> bg44;
/// Pointer to the background component of DjVu image (Raw).
GP<GPixmap> bgpm;
/// Pointer to the tqmask of foreground component of DjVu image (JB2 encoded).
GP<JB2Image> fgjb;
/// Pointer to the optional tqshape dictionary for the tqmask (JB2 encoded).
GP<JB2Dict> fgjd;
/// Pointer to a colors layer for the foreground component of DjVu image.
GP<GPixmap> fgpm;
@@ -610,7 +610,7 @@ public:
virtual bool inherits(const GUTF8String &class_name) const;
virtual void notify_chunk_done(const DjVuPort * source, const GUTF8String &name);
virtual void notify_file_flags_changed(const DjVuFile * source,
- long set_tqmask, long clr_tqmask);
+ long set_mask, long clr_mask);
virtual void set_recover_errors(const ErrorRecoveryAction=ABORT);
virtual void set_verbose_eof(const bool verbose_eof=true);
virtual void report_error(const GException &ex,const bool=true);
@@ -215,9 +215,9 @@ public:
/// Pointer to the background component of DjVu image (Raw).
GP<GPixmap> bgpm;
- /// Pointer to the tqmask of foreground component of DjVu image (JB2 encoded).
+ /// Pointer to the mask of foreground component of DjVu image (JB2 encoded).
GP<JB2Image> fgjb;
@@ -215,9 +215,9 @@ public:
GP<JB2Image> fgjb;
- /// Pointer to the optional tqshape dictionary for the tqmask (JB2 encoded).
+ /// Pointer to the optional tqshape dictionary for the mask (JB2 encoded).
GP<JB2Dict> fgjd;
/// Pointer to a colors layer for the foreground component of DjVu image.